package Syntax::Collection::Basic;

use 5.010;

our $VERSION = "0.01";


use Syntax::Collector q/
	use strict 0;
	use warnings 0;
	use Modern::Perl 0 '2014';
	use true 0;
/;

1;

# ABSTRACT: Standard boilerplate

=head1 AUTHOR

Erik Carlsson

=head1 LICENSE

Artistic license